@@ -7,8 +7,10 @@ from dynamic_preferences.registries import global_preferences_registry
 from dynamic_preferences.users import views as user_preferences_views
 from dynamic_preferences.users.registries import user_preferences_registry
 
+from bread.utils import autopath
+
 from .forms.forms import PreferencesForm, UserPreferencesForm
-from .views import auth, system
+from .views import auth, system, userprofile
 
 
 # preferences views need a bit of weird treatment, I think we coudl make this code much shorter
@@ -86,6 +88,16 @@ urlpatterns = [
     path("auth/", include("django.contrib.auth.urls")),
     path("accounts/login/", auth.BreadLoginView.as_view(), name="login"),
     path("accounts/logout/", auth.BreadLogoutView.as_view(), name="logout"),
+    path("accounts/user/", userprofile.UserProfileView.as_view(), name="userprofile"),
+    autopath(
+        userprofile.EditPersonalDataView.as_view(), urlname="userprofile.personal"
+    ),
+    autopath(userprofile.EditLoginView.as_view(), urlname="userprofile.login"),
+    autopath(userprofile.password_reset, urlname="userprofile.password_reset"),
+    autopath(
+        userprofile.EditPermissionsView.as_view(), urlname="userprofile.permissions"
+    ),
+    autopath(userprofile.set_devmode, urlname="devmode"),
     path(
         "accounts/password_reset/",
         auth.BreadPasswordResetView.as_view(),
